@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Create network transition chord progressions
 
-our $VERSION = '0.0301';
+our $VERSION = '0.0302';
 
 use Data::Dumper::Compact qw(ddc);
 use Graph::Directed;
@@ -164,10 +164,8 @@ sub generate {
         my $i = 0;
         for my $chord (@chords) {
             my $substitute = $self->sub_cond->() ? $self->substitution($chord) : $chord;
-            if ($substitute eq $chord) {
-                if ($self->sub_cond->()) {
-                    $progression[$i] .= 't';
-                }
+            if ($substitute eq $chord && $i < @progression && $self->sub_cond->()) {
+                $progression[$i] .= 't';
             }
             $chord = $substitute;
             $i++;
@@ -281,7 +279,7 @@ Music::Chord::Progression - Create network transition chord progressions
 
 =head1 VERSION
 
-version 0.0301
+version 0.0302
 
 =head1 SYNOPSIS
 
